netapp_ontap.models.consistency_group_application API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_application`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupApplicationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupApplication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `component_type: str GET POST PATCH`

    Nested consistency group tag.

    Valid choices:

    - data
    - logs
    - other
  `type: str GET POST PATCH`

    Top level consistency group tag.

    Valid choices:

    - oracle
    - other
    - exchange
    - sql_server
    - sap_hana
    - vmware
    - mongodb
    - db2
    - mysql
    - sap_maxdb
    - postgresql
    - sap_ase_sybase